@@ -67,54 +67,6 @@ eel_uri_is_other_locations (const char *uri)
     return g_str_has_prefix (uri, "other-locations:");
 }
 
-gboolean
-eel_uri_is_desktop (const char *uri)
-{
-    return g_str_has_prefix (uri, EEL_DESKTOP_URI);
-}
-
-char *
-eel_make_valid_utf8 (const char *name)
-{
-    GString *string;
-    const char *remainder, *invalid;
-    int remaining_bytes, valid_bytes;
-
-    string = NULL;
-    remainder = name;
-    remaining_bytes = strlen (name);
-
-    while (remaining_bytes != 0)
-    {
-        if (g_utf8_validate (remainder, remaining_bytes, &invalid))
-        {
-            break;
-        }
-        valid_bytes = invalid - remainder;
-
-        if (string == NULL)
-        {
-            string = g_string_sized_new (remaining_bytes);
-        }
-        g_string_append_len (string, remainder, valid_bytes);
-        g_string_append_c (string, '?');
-
-        remaining_bytes -= valid_bytes + 1;
-        remainder = invalid + 1;
-    }
-
-    if (string == NULL)
-    {
-        return g_strdup (name);
-    }
-
-    g_string_append (string, remainder);
-    g_string_append (string, _(" (invalid Unicode)"));
-    g_assert (g_utf8_validate (string->str, -1, NULL));
-
-    return g_string_free (string, FALSE);
-}
-
 char *
 eel_filename_get_extension_offset (const char *filename)
 {
