@@ -240,17 +240,15 @@ NautilusWindow *
 nautilus_application_create_window (NautilusApplication *self,
                                     GdkScreen           *screen)
 {
-    NautilusApplicationPrivate *priv;
     NautilusWindow *window;
-    char *geometry_string;
     gboolean maximized;
-    gint n_windows;
+    g_autoptr (GVariant) default_size = NULL;
+    gint default_width = 0;
+    gint default_height = 0;
 
     g_return_val_if_fail (NAUTILUS_IS_APPLICATION (self), NULL);
     nautilus_profile_start (NULL);
 
-    priv = nautilus_application_get_instance_private (self);
-    n_windows = g_list_length (priv->windows);
     window = nautilus_window_new (screen);
 
     maximized = g_settings_get_boolean
@@ -263,24 +261,14 @@ nautilus_application_create_window (NautilusApplication *self,
     {
         gtk_window_unmaximize (GTK_WINDOW (window));
     }
+    default_size = g_settings_get_value (nautilus_window_state,
+                                         NAUTILUS_WINDOW_STATE_INITIAL_SIZE);
 
-    geometry_string = g_settings_get_string
-                          (nautilus_window_state, NAUTILUS_WINDOW_STATE_GEOMETRY);
-    if (geometry_string != NULL &&
-        geometry_string[0] != 0)
-    {
-        /* Ignore saved window position if another window is already showing.
-         * That way the two windows wont appear at the exact same
-         * location on the screen.
-         */
-        eel_gtk_window_set_initial_geometry_from_string
-            (GTK_WINDOW (window),
-            geometry_string,
-            NAUTILUS_WINDOW_MIN_WIDTH,
-            NAUTILUS_WINDOW_MIN_HEIGHT,
-            n_windows > 0);
-    }
-    g_free (geometry_string);
+    g_variant_get (default_size, "(ii)", &default_width, &default_height);
+
+    gtk_window_set_default_size (GTK_WINDOW (window),
+                                 MAX (NAUTILUS_WINDOW_MIN_WIDTH, default_width),
+                                 MAX (NAUTILUS_WINDOW_MIN_HEIGHT, default_height));
 
     DEBUG ("Creating a new navigation window");
     nautilus_profile_end (NULL);
@@ -948,9 +936,7 @@ const GOptionEntry options[] =
     /* dummy, only for compatibility reasons */
     { "browser", '\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, NULL,
       NULL, NULL },
-    { "no-desktop", '\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, NULL,
-      NULL, NULL },
-    /* ditto */
+        /* ditto */
     { "geometry", 'g', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, NULL,
       N_("Create the initial window with the given geometry."), N_("GEOMETRY") },
     { "version", '\0', 0, G_OPTION_ARG_NONE, NULL,
