@@ -28,7 +28,6 @@
 #include "nautilus-global-preferences.h"
 #include "nautilus-canvas-private.h"
 #include <eel/eel-art-extensions.h>
-#include <eel/eel-gdk-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-string.h>
@@ -286,7 +285,6 @@ nautilus_canvas_item_set_property (GObject      *object,
     NautilusCanvasItem *item;
     NautilusCanvasItemDetails *details;
     AtkObject *accessible;
-    gboolean is_rename;
 
     item = NAUTILUS_CANVAS_ITEM (object);
     accessible = atk_gobject_accessible_for_object (G_OBJECT (item));
@@ -302,15 +300,13 @@ nautilus_canvas_item_set_property (GObject      *object,
                 return;
             }
 
-            is_rename = details->editable_text != NULL;
             g_free (details->editable_text);
             details->editable_text = g_strdup (g_value_get_string (value));
             if (details->text_util)
             {
                 gail_text_util_text_setup (details->text_util,
                                            details->editable_text);
-                if (is_rename)
-                    g_object_notify (G_OBJECT (accessible), "accessible-name");
+                g_object_notify (G_OBJECT (accessible), "accessible-name");
             }
 
             nautilus_canvas_item_invalidate_label_size (item);
