@@ -404,62 +404,6 @@ get_desktop_path (void)
     return desktop_path;
 }
 
-/**
- * nautilus_get_desktop_directory:
- *
- * Get the path for the directory containing files on the desktop.
- *
- * Return value: the directory path.
- **/
-char *
-nautilus_get_desktop_directory (void)
-{
-    const char *desktop_directory;
-
-    desktop_directory = get_desktop_path ();
-
-    /* Don't try to create a home directory */
-    if (!g_file_test (desktop_directory, G_FILE_TEST_EXISTS))
-    {
-        g_mkdir (desktop_directory, DEFAULT_DESKTOP_DIRECTORY_MODE);
-        /* FIXME bugzilla.gnome.org 41286:
-         * How should we handle the case where this mkdir fails?
-         * Note that nautilus_application_startup will refuse to launch if this
-         * directory doesn't get created, so that case is OK. But the directory
-         * could be deleted after Nautilus was launched, and perhaps
-         * there is some bad side-effect of not handling that case.
-         */
-    }
-
-    return g_strdup (desktop_directory);
-}
-
-GFile *
-nautilus_get_desktop_location (void)
-{
-    return g_file_new_for_path (get_desktop_path ());
-}
-
-/**
- * nautilus_get_desktop_directory_uri:
- *
- * Get the uri for the directory containing files on the desktop.
- *
- * Return value: the directory path.
- **/
-char *
-nautilus_get_desktop_directory_uri (void)
-{
-    char *desktop_path;
-    char *desktop_uri;
-
-    desktop_path = nautilus_get_desktop_directory ();
-    desktop_uri = g_filename_to_uri (desktop_path, NULL, NULL);
-    g_free (desktop_path);
-
-    return desktop_uri;
-}
-
 char *
 nautilus_get_home_directory_uri (void)
 {
@@ -595,6 +539,16 @@ nautilus_is_search_directory (GFile *dir)
     return eel_uri_is_search (uri);
 }
 
+gboolean
+nautilus_is_recent_directory (GFile *dir)
+{
+    g_autofree gchar *uri = NULL;
+
+    uri = g_file_get_uri (dir);
+
+    return eel_uri_is_recent (uri);
+}
+
 gboolean
 nautilus_is_favorite_directory (GFile *dir)
 {
@@ -608,6 +562,15 @@ nautilus_is_favorite_directory (GFile *dir)
     return FALSE;
 }
 
+gboolean
+nautilus_is_trash_directory (GFile *dir)
+{
+    g_autofree gchar *uri = NULL;
+
+    uri = g_file_get_uri (dir);
+    return eel_uri_is_trash (uri);
+}
+
 gboolean
 nautilus_is_other_locations_directory (GFile *dir)
 {
@@ -946,7 +909,7 @@ ensure_dirs_task_ready_cb (GObject      *_source,
         locations = locations_from_file_list (files);
 
         nautilus_file_operations_move
-            (locations, NULL,
+            (locations,
             original_dir_location,
             data->parent_window,
             NULL, NULL);
@@ -1331,26 +1294,67 @@ nautilus_get_common_filename_prefix (GList *file_list,
     return result;
 }
 
+static char *
+trim_whitespace (const gchar *string)
+{
+    glong space_count;
+    glong length;
+    gchar *offset;
+
+    space_count = 0;
+    length = g_utf8_strlen (string, -1);
+    offset = g_utf8_offset_to_pointer (string, length);
+
+    while (space_count <= length)
+    {
+        gunichar character;
+
+        offset = g_utf8_prev_char (offset);
+        character = g_utf8_get_char (offset);
+
+        if (!g_unichar_isspace (character))
+        {
+            break;
+        }
+
+        space_count++;
+    }
+
+    if (space_count == 0)
+    {
+        return g_strdup (string);
+    }
+
+    return g_utf8_substring (string, 0, length - space_count);
+}
+
 char *
 nautilus_get_common_filename_prefix_from_filenames (GList *filenames,
                                                     int    min_required_len)
 {
+    GList *stripped_filenames = NULL;
     char *common_prefix;
     char *truncated;
     int common_prefix_len;
 
-    common_prefix = eel_str_get_common_prefix (filenames, min_required_len);
+    for (GList *i = filenames; i != NULL; i = i->next)
+    {
+        gchar *stripped_filename;
 
+        stripped_filename = eel_filename_strip_extension (i->data);
+
+        stripped_filenames = g_list_prepend (stripped_filenames, stripped_filename);
+    }
+
+    common_prefix = eel_str_get_common_prefix (stripped_filenames, min_required_len);
     if (common_prefix == NULL)
     {
         return NULL;
     }
 
-    truncated = eel_filename_strip_extension (common_prefix);
-    g_free (common_prefix);
-    common_prefix = truncated;
+    g_list_free_full (stripped_filenames, g_free);
 
-    truncated = eel_str_rtrim_punctuation (common_prefix);
+    truncated = trim_whitespace (common_prefix);
     g_free (common_prefix);
 
     common_prefix_len = g_utf8_strlen (truncated, -1);
