@@ -32,9 +32,7 @@
  * freed with g_free, is not NULL, and is guaranteed to exist.
  */
 char *   nautilus_get_user_directory                 (void);
-char *   nautilus_get_desktop_directory              (void);
 GFile *  nautilus_get_desktop_location               (void);
-char *   nautilus_get_desktop_directory_uri          (void);
 char *   nautilus_get_home_directory_uri             (void);
 gboolean nautilus_is_desktop_directory_file          (GFile *dir,
 						      const char *filename);
@@ -45,7 +43,9 @@ gboolean nautilus_is_home_directory_file             (GFile *dir,
 						      const char *filename);
 gboolean nautilus_is_in_system_dir                   (GFile *location);
 gboolean nautilus_is_search_directory                (GFile *dir);
+gboolean nautilus_is_recent_directory                (GFile *dir);
 gboolean nautilus_is_favorite_directory              (GFile *dir);
+gboolean nautilus_is_trash_directory                 (GFile *dir);
 gboolean nautilus_is_other_locations_directory       (GFile *dir);
 GMount * nautilus_get_mounted_mount_for_root         (GFile *location);
 
