@@ -121,11 +121,6 @@ typedef void (*NautilusFileOperationCallback) (NautilusFile  *file,
 					       GFile         *result_location,
 					       GError        *error,
 					       gpointer       callback_data);
-typedef int (*NautilusWidthMeasureCallback)   (const char    *string,
-					       void	     *context);
-typedef char * (*NautilusTruncateCallback)    (const char    *string,
-					       int	      width,
-					       void	     *context);
 
 
 #define NAUTILUS_FILE_ATTRIBUTES_FOR_ICON (NAUTILUS_FILE_ATTRIBUTE_INFO | NAUTILUS_FILE_ATTRIBUTE_LINK_INFO | NAUTILUS_FILE_ATTRIBUTE_THUMBNAIL)
@@ -192,6 +187,8 @@ gboolean                nautilus_file_can_get_size                      (Nautilu
 goffset                 nautilus_file_get_size                          (NautilusFile                   *file);
 time_t                  nautilus_file_get_mtime                         (NautilusFile                   *file);
 time_t                  nautilus_file_get_atime                         (NautilusFile                   *file);
+time_t                  nautilus_file_get_recency                       (NautilusFile                   *file);
+time_t                  nautilus_file_get_trash_time                    (NautilusFile                   *file);
 GFileType               nautilus_file_get_file_type                     (NautilusFile                   *file);
 char *                  nautilus_file_get_mime_type                     (NautilusFile                   *file);
 char *                  nautilus_file_get_extension                     (NautilusFile                   *file);
@@ -211,7 +208,6 @@ gboolean                nautilus_file_is_directory                      (Nautilu
 gboolean                nautilus_file_is_regular_file                   (NautilusFile                   *file);
 gboolean                nautilus_file_is_user_special_directory         (NautilusFile                   *file,
 									 GUserDirectory                 special_directory);
-gboolean                nautilus_file_is_special_link                   (NautilusFile                   *file);
 gboolean		nautilus_file_is_archive			(NautilusFile			*file);
 gboolean                nautilus_file_is_in_search                      (NautilusFile                   *file);
 gboolean                nautilus_file_is_in_trash                       (NautilusFile                   *file);
@@ -223,7 +219,6 @@ gboolean                nautilus_file_is_other_locations                (Nautilu
 gboolean                nautilus_file_is_favorite_location              (NautilusFile                   *file);
 gboolean		nautilus_file_is_home				(NautilusFile                   *file);
 gboolean                nautilus_file_is_desktop_directory              (NautilusFile                   *file);
-gboolean                nautilus_file_is_child_of_desktop_directory     (NautilusFile                   *file);
 GError *                nautilus_file_get_file_info_error               (NautilusFile                   *file);
 gboolean                nautilus_file_get_directory_item_count          (NautilusFile                   *file,
 									 guint                          *count,
@@ -452,8 +447,7 @@ int                     nautilus_file_compare_display_name              (Nautilu
 /* filtering functions for use by various directory views */
 gboolean                nautilus_file_is_hidden_file                    (NautilusFile                   *file);
 gboolean                nautilus_file_should_show                       (NautilusFile                   *file,
-									 gboolean                        show_hidden,
-									 gboolean                        show_foreign);
+									 gboolean                        show_hidden);
 GList                  *nautilus_file_list_filter_hidden                (GList                          *files,
 									 gboolean                        show_hidden);
 
@@ -462,7 +456,6 @@ GList                  *nautilus_file_list_filter_hidden                (GList
  * Getting this can require reading the contents of the file.
  */
 gboolean                nautilus_file_is_launcher                       (NautilusFile                   *file);
-gboolean                nautilus_file_is_foreign_link                   (NautilusFile                   *file);
 gboolean                nautilus_file_is_trusted_link                   (NautilusFile                   *file);
 gboolean                nautilus_file_has_activation_uri                (NautilusFile                   *file);
 char *                  nautilus_file_get_activation_uri                (NautilusFile                   *file);
@@ -620,27 +613,6 @@ typedef struct {
 							  gpointer                        callback_data);
 
 	void                 (* poll_for_media)          (NautilusFile                   *file);
-
-        gboolean             (* can_rename)              (NautilusFile                   *file);
-
-        void                 (* rename)                  (NautilusFile                   *file,
-                                                          const char                     *new_name,
-                                                          NautilusFileOperationCallback   callback,
-                                                          gpointer                        callback_data);
-
-       char*                 (* get_target_uri)          (NautilusFile                   *file);
-
-       gboolean              (* drag_can_accept_files)   (NautilusFile                   *drop_target_item);
-
-       void                  (* invalidate_attributes_internal) (NautilusFile            *file,
-                                                                 NautilusFileAttributes   file_attributes);
-
-       gboolean              (* opens_in_view)           (NautilusFile                   *file);
-
-       /* Use this if the custom file class doesn't support usual operations like
-        * copy, delete or move.
-        */
-       gboolean              (* is_special_link)          (NautilusFile                  *file);
 } NautilusFileClass;
 
 #endif /* NAUTILUS_FILE_H */
