@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2004 Red Hat, Inc
  * Copyright (c) 2007 Novell, Inc.
+ * Copyright (c) 2017 Thomas Bechtold <thomasbechtold@jpberlin.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,20 +31,13 @@
 #include "nautilus-module.h"
 #include <string.h>
 
-#ifdef HAVE_EXIF
-  #include <libexif/exif-data.h>
-  #include <libexif/exif-ifd.h>
-  #include <libexif/exif-loader.h>
-#endif
-#ifdef HAVE_EXEMPI
-  #include <exempi/xmp.h>
-  #include <exempi/xmpconsts.h>
-#endif
+#include <gexiv2/gexiv2.h>
 
 #define LOAD_BUFFER_SIZE 8192
 
-struct NautilusImagePropertiesPageDetails
+struct _NautilusImagePropertiesPage
 {
+    GtkBox parent;
     GCancellable *cancellable;
     GtkWidget *grid;
     GdkPixbufLoader *loader;
@@ -52,22 +46,10 @@ struct NautilusImagePropertiesPageDetails
     char buffer[LOAD_BUFFER_SIZE];
     int width;
     int height;
-#ifdef HAVE_EXIF
-    ExifLoader *exifldr;
-#endif /*HAVE_EXIF*/
-#ifdef HAVE_EXEMPI
-    XmpPtr xmp;
-#endif
-};
 
-#ifdef HAVE_EXIF
-struct ExifAttribute
-{
-    ExifTag tag;
-    char *value;
-    gboolean found;
+    GExiv2Metadata *md;
+    gboolean md_ready;
 };
-#endif /*HAVE_EXIF*/
 
 enum
 {
@@ -102,11 +84,11 @@ nautilus_image_properties_page_finalize (GObject *object)
 
     page = NAUTILUS_IMAGE_PROPERTIES_PAGE (object);
 
-    if (page->details->cancellable)
+    if (page->cancellable)
     {
-        g_cancellable_cancel (page->details->cancellable);
-        g_object_unref (page->details->cancellable);
-        page->details->cancellable = NULL;
+        g_cancellable_cancel (page->cancellable);
+        g_object_unref (page->cancellable);
+        page->cancellable = NULL;
     }
 
     G_OBJECT_CLASS (nautilus_image_properties_page_parent_class)->finalize (object);
@@ -125,8 +107,8 @@ file_close_callback (GObject      *object,
 
     g_input_stream_close_finish (stream, res, NULL);
 
-    g_object_unref (page->details->cancellable);
-    page->details->cancellable = NULL;
+    g_object_unref (page->cancellable);
+    page->cancellable = NULL;
 }
 
 static void
@@ -145,7 +127,7 @@ append_item (NautilusImagePropertiesPage *page,
     pango_attr_list_unref (attrs);
     gtk_label_set_xalign (GTK_LABEL (name_label), 0);
     gtk_label_set_yalign (GTK_LABEL (name_label), 0);
-    gtk_container_add (GTK_CONTAINER (page->details->grid), name_label);
+    gtk_container_add (GTK_CONTAINER (page->grid), name_label);
     gtk_widget_show (name_label);
 
     if (value != NULL)
@@ -154,189 +136,13 @@ append_item (NautilusImagePropertiesPage *page,
         gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
         gtk_label_set_xalign (GTK_LABEL (label), 0);
         gtk_label_set_yalign (GTK_LABEL (label), 0);
-        gtk_grid_attach_next_to (GTK_GRID (page->details->grid), label,
+        gtk_grid_attach_next_to (GTK_GRID (page->grid), label,
                                  name_label, GTK_POS_RIGHT,
                                  1, 1);
         gtk_widget_show (label);
     }
 }
 
-#ifdef HAVE_EXIF
-static char *
-exif_string_to_utf8 (const char *exif_str)
-{
-    char *utf8_str;
-
-    if (g_utf8_validate (exif_str, -1, NULL))
-    {
-        return g_strdup (exif_str);
-    }
-
-    utf8_str = g_locale_to_utf8 (exif_str, -1, NULL, NULL, NULL);
-    if (utf8_str != NULL)
-    {
-        return utf8_str;
-    }
-
-    return eel_make_valid_utf8 (exif_str);
-}
-
-static void
-exif_content_callback (ExifContent *content,
-                       gpointer     data)
-{
-    struct ExifAttribute *attribute;
-    char b[1024];
-
-    attribute = (struct ExifAttribute *) data;
-    if (attribute->found)
-    {
-        return;
-    }
-
-    attribute->value = g_strdup (exif_content_get_value (content, attribute->tag, b, sizeof (b)));
-
-    if (attribute->value != NULL)
-    {
-        attribute->found = TRUE;
-    }
-}
-
-static char *
-exifdata_get_tag_name_utf8 (ExifTag tag)
-{
-    return exif_string_to_utf8 (exif_tag_get_name (tag));
-}
-
-static char *
-exifdata_get_tag_value_utf8 (ExifData *data,
-                             ExifTag   tag)
-{
-    struct ExifAttribute attribute;
-    char *utf8_value;
-
-    attribute.tag = tag;
-    attribute.value = NULL;
-    attribute.found = FALSE;
-
-    exif_data_foreach_content (data, exif_content_callback, &attribute);
-
-    if (attribute.found)
-    {
-        utf8_value = exif_string_to_utf8 (attribute.value);
-        g_free (attribute.value);
-    }
-    else
-    {
-        utf8_value = NULL;
-    }
-
-    return utf8_value;
-}
-
-static gboolean
-append_tag_value_pair (NautilusImagePropertiesPage *page,
-                       ExifData                    *data,
-                       ExifTag                      tag,
-                       char                        *description)
-{
-    char *utf_attribute;
-    char *utf_value;
-
-    utf_attribute = exifdata_get_tag_name_utf8 (tag);
-    utf_value = exifdata_get_tag_value_utf8 (data, tag);
-
-    if ((utf_attribute == NULL) || (utf_value == NULL))
-    {
-        g_free (utf_attribute);
-        g_free (utf_value);
-        return FALSE;
-    }
-
-    append_item (page,
-                 description ? description : utf_attribute,
-                 utf_value);
-
-    g_free (utf_attribute);
-    g_free (utf_value);
-
-    return TRUE;
-}
-#endif /*HAVE_EXIF*/
-
-
-#ifdef HAVE_EXEMPI
-static void
-append_xmp_value_pair (NautilusImagePropertiesPage *page,
-                       XmpPtr                       xmp,
-                       const char                  *ns,
-                       const char                  *propname,
-                       char                        *descr)
-{
-    uint32_t options;
-    XmpStringPtr value;
-
-    value = xmp_string_new ();
-    if (xmp_get_property (xmp, ns, propname, value, &options))
-    {
-        if (XMP_IS_PROP_SIMPLE (options))
-        {
-            append_item (page, descr, xmp_string_cstr (value));
-        }
-        else if (XMP_IS_PROP_ARRAY (options))
-        {
-            XmpIteratorPtr iter;
-
-            iter = xmp_iterator_new (xmp, ns, propname, XMP_ITER_JUSTLEAFNODES);
-            if (iter)
-            {
-                GString *str;
-                gboolean first = TRUE;
-
-                str = g_string_new (NULL);
-
-                while (xmp_iterator_next (iter, NULL, NULL, value, &options)
-                       && !XMP_IS_PROP_QUALIFIER (options))
-                {
-                    if (!first)
-                    {
-                        g_string_append_printf (str, ", ");
-                    }
-                    else
-                    {
-                        first = FALSE;
-                    }
-                    g_string_append_printf (str,
-                                            "%s",
-                                            xmp_string_cstr (value));
-                }
-                xmp_iterator_free (iter);
-                append_item (page, descr, g_string_free (str, FALSE));
-            }
-        }
-    }
-    xmp_string_free (value);
-}
-#endif /*HAVE EXEMPI*/
-
-static gboolean
-append_option_value_pair (NautilusImagePropertiesPage *page,
-                          GdkPixbuf                   *pixbuf,
-                          const char                  *key,
-                          char                        *description)
-{
-    const char *value;
-
-    value = gdk_pixbuf_get_option (pixbuf, key);
-    if (value == NULL)
-    {
-        return FALSE;
-    }
-
-    append_item (page, description, value);
-    return TRUE;
-}
-
 static void
 append_basic_info (NautilusImagePropertiesPage *page)
 {
@@ -345,7 +151,7 @@ append_basic_info (NautilusImagePropertiesPage *page)
     char *desc;
     char *value;
 
-    format = gdk_pixbuf_loader_get_format (page->details->loader);
+    format = gdk_pixbuf_loader_get_format (page->loader);
 
     name = gdk_pixbuf_format_get_name (format);
     desc = gdk_pixbuf_format_get_description (format);
@@ -356,107 +162,102 @@ append_basic_info (NautilusImagePropertiesPage *page)
     g_free (value);
     value = g_strdup_printf (ngettext ("%d pixel",
                                        "%d pixels",
-                                       page->details->width),
-                             page->details->width);
+                                       page->width),
+                             page->width);
     append_item (page, _("Width"), value);
     g_free (value);
     value = g_strdup_printf (ngettext ("%d pixel",
                                        "%d pixels",
-                                       page->details->height),
-                             page->details->height);
+                                       page->height),
+                             page->height);
     append_item (page, _("Height"), value);
     g_free (value);
 }
 
 static void
-append_options_info (NautilusImagePropertiesPage *page)
+append_gexiv2_tag (NautilusImagePropertiesPage  *page,
+                   const gchar                 **tag_names,
+                   const gchar                  *description)
 {
-    GdkPixbuf *pixbuf;
+    gchar *tag_value;
 
-    pixbuf = gdk_pixbuf_loader_get_pixbuf (page->details->loader);
-    if (pixbuf == NULL)
+    while (*tag_names)
     {
-        return;
-    }
-
-    if (!append_option_value_pair (page, pixbuf, "Title", _("Title")))
-    {
-        append_option_value_pair (page, pixbuf, "tEXt::Title", _("Title"));
-    }
-    if (!append_option_value_pair (page, pixbuf, "Author", _("Author")))
-    {
-        append_option_value_pair (page, pixbuf, "tEXt::Author", _("Author"));
-    }
-
-    append_option_value_pair (page, pixbuf, "tEXt::Description", _("Description"));
-    append_option_value_pair (page, pixbuf, "tEXt::Copyright", _("Copyright"));
-    append_option_value_pair (page, pixbuf, "tEXt::Creation Time", _("Created On"));
-    append_option_value_pair (page, pixbuf, "tEXt::Software", _("Created By"));
-    /* Translators: this refers to a legal disclaimer string embedded in
-     * the metadata of an image */
-    append_option_value_pair (page, pixbuf, "tEXt::Disclaimer", _("Disclaimer"));
-    append_option_value_pair (page, pixbuf, "tEXt::Warning", _("Warning"));
-    append_option_value_pair (page, pixbuf, "tEXt::Source", _("Source"));
-    append_option_value_pair (page, pixbuf, "tEXt::Comment", _("Comment"));
-}
-
-static void
-append_exif_info (NautilusImagePropertiesPage *page)
-{
-#ifdef HAVE_EXIF
-    ExifData *exifdata;
-
-    exifdata = exif_loader_get_data (page->details->exifldr);
-    if (exifdata == NULL)
-    {
-        return;
-    }
-
-    if (exifdata->ifd[0] && exifdata->ifd[0]->count)
-    {
-        append_tag_value_pair (page, exifdata, EXIF_TAG_MAKE, _("Camera Brand"));
-        append_tag_value_pair (page, exifdata, EXIF_TAG_MODEL, _("Camera Model"));
-
-        /* Choose which date to show in order of relevance */
-        if (!append_tag_value_pair (page, exifdata, EXIF_TAG_DATE_TIME_ORIGINAL, _("Date Taken")))
+        if (gexiv2_metadata_has_tag (page->md, *tag_names))
         {
-            if (!append_tag_value_pair (page, exifdata, EXIF_TAG_DATE_TIME_DIGITIZED, _("Date Digitized")))
+            tag_value = gexiv2_metadata_get_tag_interpreted_string (page->md, *tag_names);
+            if (!description)
             {
-                append_tag_value_pair (page, exifdata, EXIF_TAG_DATE_TIME, _("Date Modified"));
+                description = gexiv2_metadata_get_tag_description (*tag_names);
             }
+            /* don't add empty tags - try next one */
+            if (strlen (tag_value) > 0)
+            {
+                append_item (page, description, tag_value);
+                g_free (tag_value);
+                break;
+            }
+            g_free (tag_value);
         }
-
-        append_tag_value_pair (page, exifdata, EXIF_TAG_EXPOSURE_TIME, _("Exposure Time"));
-        append_tag_value_pair (page, exifdata, EXIF_TAG_APERTURE_VALUE, _("Aperture Value"));
-        append_tag_value_pair (page, exifdata, EXIF_TAG_ISO_SPEED_RATINGS, _("ISO Speed Rating"));
-        append_tag_value_pair (page, exifdata, EXIF_TAG_FLASH, _("Flash Fired"));
-        append_tag_value_pair (page, exifdata, EXIF_TAG_METERING_MODE, _("Metering Mode"));
-        append_tag_value_pair (page, exifdata, EXIF_TAG_EXPOSURE_PROGRAM, _("Exposure Program"));
-        append_tag_value_pair (page, exifdata, EXIF_TAG_FOCAL_LENGTH, _("Focal Length"));
-        append_tag_value_pair (page, exifdata, EXIF_TAG_SOFTWARE, _("Software"));
+        tag_names++;
     }
-
-    exif_data_unref (exifdata);
-#endif
 }
 
 static void
-append_xmp_info (NautilusImagePropertiesPage *page)
+append_gexiv2_info(NautilusImagePropertiesPage *page)
 {
-#ifdef HAVE_EXEMPI
-    if (page->details->xmp == NULL)
+    gdouble longitude, latitude, altitude;
+    gchar *gps_coords;
+
+    /* define tags and its alternatives */
+    const char *title[] = { "Xmp.dc.title", NULL };
+    const char *camera_brand[] = { "Exif.Image.Make", NULL };
+    const char *camera_model[] = { "Exif.Image.Model", "Exif.Image.UniqueCameraModel", NULL };
+    const char *created_on[] = { "Exif.Photo.DateTimeOriginal", "Xmp.xmp.CreateDate", "Exif.Image.DateTime", NULL };
+    const char *exposure_time[] = { "Exif.Photo.ExposureTime", NULL };
+    const char *aperture_value[] = { "Exif.Photo.ApertureValue", NULL };
+    const char *iso_speed_ratings[] = { "Exif.Photo.ISOSpeedRatings", "Xmp.exifEX.ISOSpeed", NULL };
+    const char *flash[] = { "Exif.Photo.Flash", NULL };
+    const char *metering_mode[] = { "Exif.Photo.MeteringMode", NULL };
+    const char *exposure_mode[] = { "Exif.Photo.ExposureMode", NULL };
+    const char *focal_length[] = { "Exif.Photo.FocalLength", NULL };
+    const char *software[] = { "Exif.Image.Software", NULL };
+    const char *description[] = { "Xmp.dc.description", "Exif.Photo.UserComment", NULL };
+    const char *subject[] = { "Xmp.dc.subject", NULL };
+    const char *creator[] = { "Xmp.dc.creator", "Exif.Image.Artist", NULL };
+    const char *rights[] = { "Xmp.dc.rights", NULL };
+    const char *rating[] = { "Xmp.xmp.Rating", NULL };
+
+    if (!page->md_ready)
     {
         return;
     }
 
-    append_xmp_value_pair (page, page->details->xmp, NS_IPTC4XMP, "Location", _("Location"));
-    append_xmp_value_pair (page, page->details->xmp, NS_DC, "description", _("Description"));
-    append_xmp_value_pair (page, page->details->xmp, NS_DC, "subject", _("Keywords"));
-    append_xmp_value_pair (page, page->details->xmp, NS_DC, "creator", _("Creator"));
-    append_xmp_value_pair (page, page->details->xmp, NS_DC, "rights", _("Copyright"));
-    append_xmp_value_pair (page, page->details->xmp, NS_XAP, "Rating", _("Rating"));
-    /* TODO add CC licenses */
-#endif /*HAVE EXEMPI*/
+    append_gexiv2_tag (page, camera_brand, _("Camera Brand"));
+    append_gexiv2_tag (page, camera_model, _("Camera Model"));
+    append_gexiv2_tag (page, exposure_time, _("Exposure Time"));
+    append_gexiv2_tag (page, exposure_mode, _("Exposure Program"));
+    append_gexiv2_tag (page, aperture_value, _("Aperture Value"));
+    append_gexiv2_tag (page, iso_speed_ratings, _("ISO Speed Rating"));
+    append_gexiv2_tag (page, flash, _("Flash Fired"));
+    append_gexiv2_tag (page, metering_mode, _("Metering Mode"));
+    append_gexiv2_tag (page, focal_length, _("Focal Length"));
+    append_gexiv2_tag (page, software, _("Software"));
+    append_gexiv2_tag (page, title, _("Title"));
+    append_gexiv2_tag (page, description, _("Description"));
+    append_gexiv2_tag (page, subject, _("Keywords"));
+    append_gexiv2_tag (page, creator, _("Creator"));
+    append_gexiv2_tag (page, created_on, _("Created On"));
+    append_gexiv2_tag (page, rights, _("Copyright"));
+    append_gexiv2_tag (page, rating, _("Rating"));
+
+    if (gexiv2_metadata_get_gps_info (page->md, &longitude, &latitude, &altitude))
+    {
+        /* Translators: These are the coordinates of a position where a picture was taken. */
+        gps_coords = g_strdup_printf (_("%f N / %f W (%.0f m)"), latitude, longitude, altitude);
+        append_item (page, _("Coordinates"), gps_coords);
+        g_free (gps_coords);
+    }
 }
 
 static void
@@ -464,45 +265,31 @@ load_finished (NautilusImagePropertiesPage *page)
 {
     GtkWidget *label;
 
-    label = gtk_grid_get_child_at (GTK_GRID (page->details->grid), 0, 0);
-    gtk_container_remove (GTK_CONTAINER (page->details->grid), label);
+    label = gtk_grid_get_child_at (GTK_GRID (page->grid), 0, 0);
+    gtk_container_remove (GTK_CONTAINER (page->grid), label);
 
-    if (page->details->loader != NULL)
+    if (page->loader != NULL)
     {
-        gdk_pixbuf_loader_close (page->details->loader, NULL);
+        gdk_pixbuf_loader_close (page->loader, NULL);
     }
 
-    if (page->details->got_size)
+    if (page->got_size)
     {
         append_basic_info (page);
-        append_options_info (page);
-        append_exif_info (page);
-        append_xmp_info (page);
+        append_gexiv2_info (page);
     }
     else
     {
         append_item (page, _("Failed to load image information"), NULL);
     }
 
-    if (page->details->loader != NULL)
+    if (page->loader != NULL)
     {
-        g_object_unref (page->details->loader);
-        page->details->loader = NULL;
+        g_object_unref (page->loader);
+        page->loader = NULL;
     }
-#ifdef HAVE_EXIF
-    if (page->details->exifldr != NULL)
-    {
-        exif_loader_unref (page->details->exifldr);
-        page->details->exifldr = NULL;
-    }
-#endif /*HAVE_EXIF*/
-#ifdef HAVE_EXEMPI
-    if (page->details->xmp != NULL)
-    {
-        xmp_free (page->details->xmp);
-        page->details->xmp = NULL;
-    }
-#endif
+    page->md_ready = FALSE;
+    g_clear_object (&page->md);
 }
 
 static void
@@ -514,7 +301,6 @@ file_read_callback (GObject      *object,
     GInputStream *stream;
     gssize count_read;
     GError *error;
-    int exif_still_loading;
     gboolean done_reading;
 
     page = NAUTILUS_IMAGE_PROPERTIES_PAGE (data);
@@ -526,35 +312,26 @@ file_read_callback (GObject      *object,
 
     if (count_read > 0)
     {
-        g_assert (count_read <= sizeof (page->details->buffer));
+        g_assert (count_read <= sizeof (page->buffer));
 
-#ifdef HAVE_EXIF
-        exif_still_loading = exif_loader_write (page->details->exifldr,
-                                                (guchar *) page->details->buffer,
-                                                count_read);
-#else
-        exif_still_loading = 0;
-#endif
-
-        if (page->details->pixbuf_still_loading)
+        if (page->pixbuf_still_loading)
         {
-            if (!gdk_pixbuf_loader_write (page->details->loader,
-                                          (const guchar *) page->details->buffer,
+            if (!gdk_pixbuf_loader_write (page->loader,
+                                          (const guchar *) page->buffer,
                                           count_read,
                                           NULL))
             {
-                page->details->pixbuf_still_loading = FALSE;
+                page->pixbuf_still_loading = FALSE;
             }
         }
 
-        if (page->details->pixbuf_still_loading ||
-            (exif_still_loading == 1))
+        if (page->pixbuf_still_loading)
         {
             g_input_stream_read_async (G_INPUT_STREAM (stream),
-                                       page->details->buffer,
-                                       sizeof (page->details->buffer),
+                                       page->buffer,
+                                       sizeof (page->buffer),
                                        0,
-                                       page->details->cancellable,
+                                       page->cancellable,
                                        file_read_callback,
                                        page);
         }
@@ -582,7 +359,7 @@ file_read_callback (GObject      *object,
         load_finished (page);
         g_input_stream_close_async (stream,
                                     0,
-                                    page->details->cancellable,
+                                    page->cancellable,
                                     file_close_callback,
                                     page);
     }
@@ -598,10 +375,10 @@ size_prepared_callback (GdkPixbufLoader *loader,
 
     page = NAUTILUS_IMAGE_PROPERTIES_PAGE (callback_data);
 
-    page->details->height = height;
-    page->details->width = width;
-    page->details->got_size = TRUE;
-    page->details->pixbuf_still_loading = FALSE;
+    page->height = height;
+    page->width = width;
+    page->got_size = TRUE;
+    page->pixbuf_still_loading = FALSE;
 }
 
 typedef struct
@@ -632,30 +409,27 @@ file_open_callback (GObject      *object,
         char *mime_type;
 
         mime_type = nautilus_file_info_get_mime_type (data->info);
-        page->details->loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, &error);
+        page->loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, &error);
         if (error != NULL)
         {
             g_warning ("Error creating loader for %s: %s", uri, error->message);
             g_clear_error (&error);
         }
-        page->details->pixbuf_still_loading = TRUE;
-        page->details->width = 0;
-        page->details->height = 0;
-#ifdef HAVE_EXIF
-        page->details->exifldr = exif_loader_new ();
-#endif /*HAVE_EXIF*/
+        page->pixbuf_still_loading = TRUE;
+        page->width = 0;
+        page->height = 0;
         g_free (mime_type);
 
-        g_signal_connect (page->details->loader,
+        g_signal_connect (page->loader,
                           "size-prepared",
                           G_CALLBACK (size_prepared_callback),
                           page);
 
         g_input_stream_read_async (G_INPUT_STREAM (stream),
-                                   page->details->buffer,
-                                   sizeof (page->details->buffer),
+                                   page->buffer,
+                                   sizeof (page->buffer),
                                    0,
-                                   page->details->cancellable,
+                                   page->cancellable,
                                    file_read_callback,
                                    page);
 
@@ -678,37 +452,43 @@ load_location (NautilusImagePropertiesPage *page,
 {
     GFile *file;
     char *uri;
+    gchar *file_path;
     FileOpenData *data;
+    GError *err;
 
     g_assert (NAUTILUS_IS_IMAGE_PROPERTIES_PAGE (page));
     g_assert (info != NULL);
 
-    page->details->cancellable = g_cancellable_new ();
+    err = NULL;
+    page->cancellable = g_cancellable_new ();
 
     uri = nautilus_file_info_get_uri (info);
     file = g_file_new_for_uri (uri);
+    file_path = g_file_get_path (file);
 
-#ifdef HAVE_EXEMPI
-    {
-        /* Current Exempi does not support setting custom IO to be able to use Gnome-vfs */
-        /* So it will only work with local files. Future version might remove this limitation */
-        XmpFilePtr xf;
-        char *localname;
-
-        localname = g_filename_from_uri (uri, NULL, NULL);
-        if (localname)
-        {
-            xf = xmp_files_open_new (localname, 0);
-            page->details->xmp = xmp_files_get_new_xmp (xf);             /* only load when loading */
-            xmp_files_close (xf, 0);
-            g_free (localname);
-        }
+    /* gexiv2 metadata init */
+    page->md_ready = gexiv2_initialize ();
+    if (!page->md_ready)
+      {
+        g_warning ("Unable to initialize gexiv2");
+      }
+    else
+      {
+        page->md = gexiv2_metadata_new ();
+        if (file_path)
+          {
+            if (!gexiv2_metadata_open_path (page->md, file_path, &err))
+              {
+                g_warning ("gexiv2 metadata not supported for '%s': %s", file_path, err->message);
+                g_clear_error (&err);
+                page->md_ready = FALSE;
+              }
+          }
         else
-        {
-            page->details->xmp = NULL;
-        }
-    }
-#endif /*HAVE_EXEMPI*/
+          {
+            page->md_ready = FALSE;
+          }
+      }
 
     data = g_new0 (FileOpenData, 1);
     data->page = page;
@@ -716,12 +496,13 @@ load_location (NautilusImagePropertiesPage *page,
 
     g_file_read_async (file,
                        0,
-                       page->details->cancellable,
+                       page->cancellable,
                        file_open_callback,
                        data);
 
     g_object_unref (file);
     g_free (uri);
+    g_free (file_path);
 }
 
 static void
@@ -732,8 +513,6 @@ nautilus_image_properties_page_class_init (NautilusImagePropertiesPageClass *cla
     object_class = G_OBJECT_CLASS (class);
 
     object_class->finalize = nautilus_image_properties_page_finalize;
-
-    g_type_class_add_private (object_class, sizeof (NautilusImagePropertiesPageDetails));
 }
 
 static void
@@ -741,10 +520,6 @@ nautilus_image_properties_page_init (NautilusImagePropertiesPage *page)
 {
     GtkWidget *sw;
 
-    page->details = G_TYPE_INSTANCE_GET_PRIVATE (page,
-                                                 NAUTILUS_TYPE_IMAGE_PROPERTIES_PAGE,
-                                                 NautilusImagePropertiesPageDetails);
-
     gtk_orientable_set_orientation (GTK_ORIENTABLE (page), GTK_ORIENTATION_VERTICAL);
     gtk_box_set_homogeneous (GTK_BOX (page), FALSE);
     gtk_box_set_spacing (GTK_BOX (page), 0);
@@ -758,13 +533,13 @@ nautilus_image_properties_page_init (NautilusImagePropertiesPage *page)
                                     GTK_POLICY_AUTOMATIC);
     gtk_box_pack_start (GTK_BOX (page), sw, FALSE, TRUE, 2);
 
-    page->details->grid = gtk_grid_new ();
-    gtk_container_set_border_width (GTK_CONTAINER (page->details->grid), 6);
-    gtk_orientable_set_orientation (GTK_ORIENTABLE (page->details->grid), GTK_ORIENTATION_VERTICAL);
-    gtk_grid_set_row_spacing (GTK_GRID (page->details->grid), 6);
-    gtk_grid_set_column_spacing (GTK_GRID (page->details->grid), 20);
+    page->grid = gtk_grid_new ();
+    gtk_container_set_border_width (GTK_CONTAINER (page->grid), 6);
+    gtk_orientable_set_orientation (GTK_ORIENTABLE (page->grid), GTK_ORIENTATION_VERTICAL);
+    gtk_grid_set_row_spacing (GTK_GRID (page->grid), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (page->grid), 20);
     append_item (page, _("Loading…"), NULL);
-    gtk_container_add (GTK_CONTAINER (sw), page->details->grid);
+    gtk_container_add (GTK_CONTAINER (sw), page->grid);
 
     gtk_widget_show_all (GTK_WIDGET (page));
 }
