@@ -88,11 +88,14 @@ find_tab_num_at_pos (NautilusNotebook *notebook,
                      gint              abs_x,
                      gint              abs_y)
 {
+    GtkPositionType tab_pos;
     int page_num = 0;
     GtkNotebook *nb = GTK_NOTEBOOK (notebook);
     GtkWidget *page;
     GtkAllocation allocation;
 
+    tab_pos = gtk_notebook_get_tab_pos (GTK_NOTEBOOK (notebook));
+
     while ((page = gtk_notebook_get_nth_page (nb, page_num)))
     {
         GtkWidget *tab;
@@ -115,7 +118,15 @@ find_tab_num_at_pos (NautilusNotebook *notebook,
         max_x = x_root + allocation.x + allocation.width;
         max_y = y_root + allocation.y + allocation.height;
 
-        if (abs_x <= max_x && abs_y <= max_y)
+        if (((tab_pos == GTK_POS_TOP)
+             || (tab_pos == GTK_POS_BOTTOM))
+            && (abs_x <= max_x))
+        {
+            return page_num;
+        }
+        else if (((tab_pos == GTK_POS_LEFT)
+                  || (tab_pos == GTK_POS_RIGHT))
+                 && (abs_y <= max_y))
         {
             return page_num;
         }
@@ -143,27 +154,14 @@ button_press_cb (NautilusNotebook *notebook,
             /* consume event, so that we don't pop up the context menu when
              * the mouse if not over a tab label
              */
-            return GDK_EVENT_STOP;
+            return TRUE;
         }
 
         /* switch to the page the mouse is over, but don't consume the event */
         gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), tab_clicked);
     }
-    else if (event->type == GDK_BUTTON_PRESS &&
-             event->button == GDK_BUTTON_MIDDLE)
-    {
-        GtkWidget *slot;
 
-        if (tab_clicked == -1)
-        {
-            return GDK_EVENT_PROPAGATE;
-        }
-
-        slot = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), tab_clicked);
-        g_signal_emit (notebook, signals[TAB_CLOSE_REQUEST], 0, slot);
-    }
-
-    return GDK_EVENT_PROPAGATE;
+    return FALSE;
 }
 
 static void
@@ -405,6 +403,7 @@ nautilus_notebook_add_tab (NautilusNotebook   *notebook,
     gtk_container_child_set (GTK_CONTAINER (notebook),
                              GTK_WIDGET (slot),
                              "tab-expand", TRUE,
+                             "detachable", FALSE,
                              NULL);
 
     nautilus_notebook_sync_tab_label (notebook, slot);
