@@ -102,7 +102,7 @@ typedef struct
 
     GMenu *context_menu;
     NautilusFile *context_menu_file;
-    GdkEventButton *context_menu_event;
+    GdkEvent *context_menu_event;
 } NautilusPathBarPrivate;
 
 
@@ -1626,9 +1626,9 @@ real_pop_up_pathbar_context_menu (NautilusPathBar *self)
 
     priv = nautilus_path_bar_get_instance_private (self);
 
-    nautilus_pop_up_context_menu (GTK_WIDGET (self),
-                                  priv->context_menu,
-                                  priv->context_menu_event);
+    nautilus_pop_up_context_menu_at_pointer (GTK_WIDGET (self),
+                                             priv->context_menu,
+                                             priv->context_menu_event);
 }
 
 static void
@@ -1680,7 +1680,7 @@ schedule_pop_up_context_menu (NautilusPathBar *self,
     {
         gdk_event_free ((GdkEvent *) priv->context_menu_event);
     }
-    priv->context_menu_event = (GdkEventButton *) gdk_event_copy ((GdkEvent *) event);
+    priv->context_menu_event = gdk_event_copy ((GdkEvent *) event);
 
     if (file == priv->context_menu_file)
     {
