@@ -324,18 +324,6 @@ pixbuf_can_load_type (const char *mime_type)
     return FALSE;
 }
 
-gboolean
-nautilus_can_thumbnail_internally (NautilusFile *file)
-{
-    char *mime_type;
-    gboolean res;
-
-    mime_type = nautilus_file_get_mime_type (file);
-    res = pixbuf_can_load_type (mime_type);
-    g_free (mime_type);
-    return res;
-}
-
 gboolean
 nautilus_thumbnail_is_mimetype_limited_by_size (const char *mime_type)
 {
