@@ -387,29 +387,36 @@ real_select_all (NautilusFilesView *files_view)
     gtk_flow_box_select_all (GTK_FLOW_BOX (self->view_ui));
 }
 
-static void
-real_reveal_selection (NautilusFilesView *files_view)
+static GtkWidget *
+get_first_selected_item_ui (NautilusViewIconController *self)
 {
-    GList *selection;
+    g_autoptr (GList) selection = NULL;
+    NautilusFile *file;
     NautilusViewItemModel *item_model;
-    NautilusViewIconController *self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
-    GtkWidget *item_ui;
+
+    selection = nautilus_view_get_selection (NAUTILUS_VIEW (self));
+    if (selection == NULL)
+    {
+        return NULL;
+    }
+
+    file = NAUTILUS_FILE (selection->data);
+    item_model = nautilus_view_model_get_item_from_file (self->model, file);
+
+    return nautilus_view_item_model_get_item_ui (item_model);
+}
+
+static void
+reveal_item_ui (NautilusViewIconController *self,
+                GtkWidget                  *item_ui)
+{
     GtkAllocation allocation;
     GtkWidget *content_widget;
     GtkAdjustment *vadjustment;
     int view_height;
 
-    selection = nautilus_view_get_selection (NAUTILUS_VIEW (files_view));
-    if (selection == NULL)
-    {
-        return;
-    }
-
-    item_model = nautilus_view_model_get_item_from_file (self->model,
-                                                         NAUTILUS_FILE (selection->data));
-    item_ui = nautilus_view_item_model_get_item_ui (item_model);
     gtk_widget_get_allocation (item_ui, &allocation);
-    content_widget = nautilus_files_view_get_content_widget (files_view);
+    content_widget = nautilus_files_view_get_content_widget (NAUTILUS_FILES_VIEW (self));
     view_height = gtk_widget_get_allocated_height (content_widget);
     vadjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (content_widget));
 
@@ -425,8 +432,20 @@ real_reveal_selection (NautilusFilesView *files_view)
         gtk_adjustment_set_value (vadjustment,
                                   allocation.y + allocation.height - view_height);
     }
+}
 
-    g_list_foreach (selection, (GFunc) g_object_unref, NULL);
+static void
+real_reveal_selection (NautilusFilesView *files_view)
+{
+    NautilusViewIconController *self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
+    GtkWidget *item_ui;
+
+    item_ui = get_first_selected_item_ui (self);
+
+    if (item_ui != NULL)
+    {
+        reveal_item_ui (self, item_ui);
+    }
 }
 
 static gboolean
@@ -608,35 +627,64 @@ real_can_zoom_out (NautilusFilesView *files_view)
 }
 
 static GdkRectangle *
-real_compute_rename_popover_pointing_to (NautilusFilesView *files_view)
+get_rectangle_for_item_ui (NautilusViewIconController *self,
+                           GtkWidget                  *item_ui)
 {
-    NautilusViewIconController *self;
-    GdkRectangle *allocation;
+    GdkRectangle *rectangle;
+    GtkWidget *content_widget;
     GtkAdjustment *vadjustment;
     GtkAdjustment *hadjustment;
-    GtkWidget *parent_container;
-    g_autoptr (GQueue) selection_files = NULL;
-    g_autoptr (GQueue) selection_item_models = NULL;
-    GList *selection;
-    GtkWidget *icon_item_ui;
 
-    self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
-    allocation = g_new0 (GdkRectangle, 1);
+    rectangle = g_new0 (GdkRectangle, 1);
+    gtk_widget_get_allocation (item_ui, rectangle);
+
+    content_widget = nautilus_files_view_get_content_widget (NAUTILUS_FILES_VIEW (self));
+    vadjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (content_widget));
+    hadjustment = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (content_widget));
+
+    rectangle->x -= gtk_adjustment_get_value (hadjustment);
+    rectangle->y -= gtk_adjustment_get_value (vadjustment);
+
+    return rectangle;
+}
+
+static GdkRectangle *
+real_compute_rename_popover_pointing_to (NautilusFilesView *files_view)
+{
+    NautilusViewIconController *self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
+    GtkWidget *item_ui;
 
-    parent_container = nautilus_files_view_get_content_widget (files_view);
-    vadjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (parent_container));
-    hadjustment = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (parent_container));
-    selection = nautilus_view_get_selection (NAUTILUS_VIEW (files_view));
-    selection_files = convert_glist_to_queue (selection);
-    selection_item_models = nautilus_view_model_get_items_from_files (self->model, selection_files);
     /* We only allow one item to be renamed with a popover */
-    icon_item_ui = nautilus_view_item_model_get_item_ui (g_queue_peek_head (selection_item_models));
-    gtk_widget_get_allocation (icon_item_ui, allocation);
+    item_ui = get_first_selected_item_ui (self);
+    g_return_val_if_fail (item_ui != NULL, NULL);
 
-    allocation->x -= gtk_adjustment_get_value (hadjustment);
-    allocation->y -= gtk_adjustment_get_value (vadjustment);
+    return get_rectangle_for_item_ui (self, item_ui);
+}
 
-    return allocation;
+static GdkRectangle *
+real_reveal_for_selection_context_menu (NautilusFilesView *files_view)
+{
+    g_autoptr (GList) selection = NULL;
+    NautilusViewIconController *self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
+    GtkWidget *item_ui;
+
+    selection = nautilus_view_get_selection (NAUTILUS_VIEW (files_view));
+    g_return_val_if_fail (selection != NULL, NULL);
+
+    /* Get the focused item_ui, if selected.
+     * Otherwise, get the selected item_ui which is sorted the lowest.*/
+    item_ui = gtk_container_get_focus_child (GTK_CONTAINER (self->view_ui));
+    if (item_ui == NULL || !gtk_flow_box_child_is_selected (GTK_FLOW_BOX_CHILD (item_ui)))
+    {
+        g_autoptr (GList) list = gtk_flow_box_get_selected_children (GTK_FLOW_BOX (self->view_ui));
+
+        list = g_list_last (list);
+        item_ui = GTK_WIDGET (list->data);
+    }
+
+    reveal_item_ui (self, item_ui);
+
+    return get_rectangle_for_item_ui (self, item_ui);
 }
 
 static void
@@ -683,7 +731,7 @@ on_button_press_event (GtkWidget *widget,
         if (event_button->button == GDK_BUTTON_SECONDARY)
         {
             nautilus_files_view_pop_up_selection_context_menu (NAUTILUS_FILES_VIEW (self),
-                                                               event_button);
+                                                               event);
         }
     }
     else
@@ -692,7 +740,7 @@ on_button_press_event (GtkWidget *widget,
         if (event_button->button == GDK_BUTTON_SECONDARY)
         {
             nautilus_files_view_pop_up_background_context_menu (NAUTILUS_FILES_VIEW (self),
-                                                                event_button);
+                                                                event);
         }
     }
 
@@ -719,12 +767,6 @@ real_compare_files (NautilusFilesView *files_view,
     return 0;
 }
 
-static gboolean
-real_using_manual_layout (NautilusFilesView *files_view)
-{
-    return FALSE;
-}
-
 static void
 real_end_loading (NautilusFilesView *files_view,
                   gboolean           all_files_seen)
@@ -926,7 +968,6 @@ nautilus_view_icon_controller_class_init (NautilusViewIconControllerClass *klass
     files_view_class->compare_files = real_compare_files;
     files_view_class->sort_directories_first_changed = real_sort_directories_first_changed;
     files_view_class->end_file_changes = real_end_file_changes;
-    files_view_class->using_manual_layout = real_using_manual_layout;
     files_view_class->end_loading = real_end_loading;
     files_view_class->get_view_id = real_get_view_id;
     files_view_class->get_first_visible_file = real_get_first_visible_file;
@@ -937,6 +978,7 @@ nautilus_view_icon_controller_class_init (NautilusViewIconControllerClass *klass
     files_view_class->get_zoom_level_percentage = real_get_zoom_level_percentage;
     files_view_class->is_zoom_level_default = real_is_zoom_level_default;
     files_view_class->compute_rename_popover_pointing_to = real_compute_rename_popover_pointing_to;
+    files_view_class->reveal_for_selection_context_menu = real_reveal_for_selection_context_menu;
 }
 
 static void
