@@ -46,9 +46,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#ifdef HAVE_X11_XF86KEYSYM_H
-#include <X11/XF86keysym.h>
-#endif
 #include "nautilus-dnd.h"
 #include "nautilus-file-utilities.h"
 #include "nautilus-file-attributes.h"
@@ -137,8 +134,6 @@ typedef struct
     /* focus widget before the location bar has been shown temporarily */
     GtkWidget *last_focus_widget;
 
-    gboolean disable_chrome;
-
     guint sidebar_width_handler_id;
     guint bookmarks_id;
 
@@ -147,12 +142,6 @@ typedef struct
     GtkPadController *pad_controller;
 } NautilusWindowPrivate;
 
-enum
-{
-    PROP_DISABLE_CHROME = 1,
-    NUM_PROPERTIES,
-};
-
 enum
 {
     SLOT_ADDED,
@@ -161,7 +150,6 @@ enum
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
-static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
 G_DEFINE_TYPE_WITH_PRIVATE (NautilusWindow, nautilus_window, GTK_TYPE_APPLICATION_WINDOW);
 
@@ -171,21 +159,19 @@ static const struct
     const char *action;
 } extra_window_keybindings [] =
 {
-#ifdef HAVE_X11_XF86KEYSYM_H
     /* Window actions */
-    { XF86XK_AddFavorite, "bookmark-current-location" },
-    { XF86XK_Favorites, "bookmarks" },
-    { XF86XK_Go, "enter-location" },
-    { XF86XK_HomePage, "go-home" },
-    { XF86XK_OpenURL, "enter-location" },
-    { XF86XK_Refresh, "reload" },
-    { XF86XK_Reload, "reload" },
-    { XF86XK_Search, "search" },
-    { XF86XK_Start, "go-home" },
-    { XF86XK_Stop, "stop" },
-    { XF86XK_Back, "back" },
-    { XF86XK_Forward, "forward" },
-#endif
+    { GDK_KEY_AddFavorite, "bookmark-current-location" },
+    { GDK_KEY_Favorites, "bookmarks" },
+    { GDK_KEY_Go, "enter-location" },
+    { GDK_KEY_HomePage, "go-home" },
+    { GDK_KEY_OpenURL, "enter-location" },
+    { GDK_KEY_Refresh, "reload" },
+    { GDK_KEY_Reload, "reload" },
+    { GDK_KEY_Search, "search" },
+    { GDK_KEY_Start, "go-home" },
+    { GDK_KEY_Stop, "stop" },
+    { GDK_KEY_Back, "back" },
+    { GDK_KEY_Forward, "forward" },
 };
 
 static const GtkPadActionEntry pad_actions[] = {
@@ -1291,7 +1277,7 @@ places_sidebar_drag_perform_drop_cb (GtkPlacesSidebar *sidebar,
     dest_uri = g_file_get_uri (dest_file);
     source_uri_list = build_uri_list_from_gfile_list (source_file_list);
 
-    nautilus_file_operations_copy_move (source_uri_list, NULL, dest_uri, action, GTK_WIDGET (sidebar), NULL, NULL);
+    nautilus_file_operations_copy_move (source_uri_list, dest_uri, action, GTK_WIDGET (sidebar), NULL, NULL);
 
     g_free (dest_uri);
     g_list_free_full (source_uri_list, g_free);
@@ -1564,11 +1550,6 @@ nautilus_window_show_sidebar (NautilusWindow *window)
 
     priv = nautilus_window_get_instance_private (window);
 
-    if (priv->disable_chrome)
-    {
-        return;
-    }
-
     gtk_widget_show (priv->sidebar);
     setup_side_pane_width (window);
 }
@@ -1829,8 +1810,7 @@ nautilus_window_on_undo_changed (NautilusFileUndoManager *manager,
 
     if (undo_info != NULL &&
         state == NAUTILUS_FILE_UNDO_MANAGER_STATE_UNDO &&
-        nautilus_file_undo_info_get_op_type (undo_info) == NAUTILUS_FILE_UNDO_OP_MOVE_TO_TRASH &&
-        !priv->disable_chrome)
+        nautilus_file_undo_info_get_op_type (undo_info) == NAUTILUS_FILE_UNDO_OP_MOVE_TO_TRASH)
     {
         files = nautilus_file_undo_info_trash_get_files (NAUTILUS_FILE_UNDO_INFO_TRASH (undo_info));
 
@@ -1913,8 +1893,7 @@ nautilus_window_show_operation_notification (NautilusWindow *window,
 
     priv = nautilus_window_get_instance_private (window);
     current_location = nautilus_window_slot_get_location (priv->active_slot);
-    if (gtk_window_has_toplevel_focus (GTK_WINDOW (window)) &&
-        !priv->disable_chrome)
+    if (gtk_window_has_toplevel_focus (GTK_WINDOW (window)))
     {
         remove_notifications (window);
         gtk_label_set_text (GTK_LABEL (priv->notification_operation_label),
@@ -2112,9 +2091,6 @@ setup_toolbar (NautilusWindow *window)
     priv = nautilus_window_get_instance_private (window);
 
     g_object_set (priv->toolbar, "window", window, NULL);
-    g_object_bind_property (window, "disable-chrome",
-                            priv->toolbar, "visible",
-                            G_BINDING_INVERT_BOOLEAN);
 
     /* connect to the pathbar signals */
     path_bar = nautilus_toolbar_get_path_bar (NAUTILUS_TOOLBAR (priv->toolbar));
@@ -2398,56 +2374,6 @@ nautilus_window_constructed (GObject *self)
     nautilus_profile_end (NULL);
 }
 
-static void
-nautilus_window_set_property (GObject      *object,
-                              guint         arg_id,
-                              const GValue *value,
-                              GParamSpec   *pspec)
-{
-    NautilusWindow *window;
-    window = NAUTILUS_WINDOW (object);
-    NautilusWindowPrivate *priv;
-
-    priv = nautilus_window_get_instance_private (window);
-
-    switch (arg_id)
-    {
-        case PROP_DISABLE_CHROME:
-        {
-            priv->disable_chrome = g_value_get_boolean (value);
-        }
-        break;
-
-        default:
-        {
-            G_OBJECT_WARN_INVALID_PROPERTY_ID (object, arg_id, pspec);
-        }
-        break;
-    }
-}
-
-static void
-nautilus_window_get_property (GObject    *object,
-                              guint       arg_id,
-                              GValue     *value,
-                              GParamSpec *pspec)
-{
-    NautilusWindow *window;
-    window = NAUTILUS_WINDOW (object);
-    NautilusWindowPrivate *priv;
-
-    priv = nautilus_window_get_instance_private (window);
-
-    switch (arg_id)
-    {
-        case PROP_DISABLE_CHROME:
-        {
-            g_value_set_boolean (value, priv->disable_chrome);
-        }
-        break;
-    }
-}
-
 static gint
 sort_slots_active_last (NautilusWindowSlot *a,
                         NautilusWindowSlot *b,
@@ -2579,24 +2505,28 @@ nautilus_window_finalize (GObject *object)
 static void
 nautilus_window_save_geometry (NautilusWindow *window)
 {
-    char *geometry_string;
     gboolean is_maximized;
 
     g_assert (NAUTILUS_IS_WINDOW (window));
 
     if (gtk_widget_get_window (GTK_WIDGET (window)))
     {
-        geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
+        gint width;
+        gint height;
+        GVariant *initial_size;
+
+        gtk_window_get_size (GTK_WINDOW (window), &width, &height);
+
+        initial_size = g_variant_new_parsed ("(%i, %i)", width, height);
         is_maximized = gdk_window_get_state (gtk_widget_get_window (GTK_WIDGET (window)))
                        & GDK_WINDOW_STATE_MAXIMIZED;
 
         if (!is_maximized)
         {
-            g_settings_set_string
-                (nautilus_window_state, NAUTILUS_WINDOW_STATE_GEOMETRY,
-                geometry_string);
+            g_settings_set_value (nautilus_window_state,
+                                  NAUTILUS_WINDOW_STATE_INITIAL_SIZE,
+                                  initial_size);
         }
-        g_free (geometry_string);
 
         g_settings_set_boolean
             (nautilus_window_state, NAUTILUS_WINDOW_STATE_MAXIMIZED,
@@ -2927,8 +2857,6 @@ nautilus_window_class_init (NautilusWindowClass *class)
 
     oclass->finalize = nautilus_window_finalize;
     oclass->constructed = nautilus_window_constructed;
-    oclass->get_property = nautilus_window_get_property;
-    oclass->set_property = nautilus_window_set_property;
 
     wclass->destroy = nautilus_window_destroy;
     wclass->show = nautilus_window_show;
@@ -2962,13 +2890,6 @@ nautilus_window_class_init (NautilusWindowClass *class)
     gtk_widget_class_bind_template_callback (wclass, places_sidebar_show_other_locations_with_flags);
     gtk_widget_class_bind_template_callback (wclass, places_sidebar_show_starred_location);
 
-    properties[PROP_DISABLE_CHROME] =
-        g_param_spec_boolean ("disable-chrome",
-                              "Disable chrome",
-                              "Disable window chrome, for the desktop",
-                              FALSE,
-                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
-                              G_PARAM_STATIC_STRINGS);
     signals[SLOT_ADDED] =
         g_signal_new ("slot-added",
                       G_TYPE_FROM_CLASS (class),
@@ -3003,8 +2924,6 @@ nautilus_window_class_init (NautilusWindowClass *class)
 
     gtk_widget_class_bind_template_callback (wclass, on_notification_operation_open_clicked);
     gtk_widget_class_bind_template_callback (wclass, on_notification_operation_close_clicked);
-
-    g_object_class_install_properties (oclass, NUM_PROPERTIES, properties);
 }
 
 NautilusWindow *
